==> xkeycaps-2.29-3.tar.gz: xkeycaps-2.29/kbds/hpitf-caps.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the key surfaces of the HP 300, 400, and 700 series
 * keyboards.  By Dave Brooks <dbrooks@inel.gov>
 */

static struct key_strings hpitf_caps [] = {

  /* Row 0 */

  {"Reset", "Break", 0},
  {"Stop", 0},
  {"F1", 0},
  {"F2", 0},
  {"F3", 0},
  {"F4", 0},
  {"Menu", 0},
  {"User", "System", 0},
  {"F5", 0},
  {"F6", 0},
  {"F7", 0},
  {"F8", 0},
  {"Clear", "line", 0},
  {"Clear", "display", 0},
  {"F9", 0},
  {"F10", 0},
  {"F11", 0},
  {"F12", 0},

  /* Row 2 */

  {"~", "`", 0},
  {"!", "1", 0},
  {"@", "2", 0},
  {"#", "3", 0},
  {"$", "4", 0},
  {"%", "5", 0},
  {"^", "6", 0},
  {"&", "7", 0},
  {"*", "8", 0},
  {"(", "9", 0},
  {")", "0", 0},
  {"_", "-", 0},
  {"+", "=", 0},
  {"Backspace", 0},
  {"Insert", "line", 0},
  {"Delete", "line", 0},
  {"*", 0},
  {"/", 0},
  {"+", 0},
  {"-", 0},

  /* Row 3 */

  {"Tab", 0},
  {"Q", 0},
  {"W", 0},
  {"E", 0},
  {"R", 0},
  {"T", 0},
  {"Y", 0},
  {"U", 0},
  {"I", 0},
  {"O", 0},
  {"P", 0},
  {"{", "[", 0},
  {"}", "]", 0},
  {"|", "\\", 0},
  {"Insert", "char", 0},
  {"Delete", "char", 0},
  {"7", 0},
  {"8", 0},
  {"9", 0},
  {"Enter", 0},

  /* Row 4 */

  {"Caps", 0},
  {"Ctrl", 0},
  {"A", 0},
  {"S", 0},
  {"D", 0},
  {"F", 0},
  {"G", 0},
  {"H", 0},
  {"J", 0},
  {"K", 0},
  {"L", 0},
  {":", ";", 0},
  {"\"", "'", 0},
  {"Return", 0},
  {"Home", 0},
  {"Prev", 0},
  {"4", 0},
  {"5", 0},
  {"6", 0},
  {",", 0},

  /* Row 5 */

  {"Del", "Esc", 0},
  {"Shift", 0},
  {"Z", 0},
  {"X", 0},
  {"C", 0},
  {"V", 0},
  {"B", 0},
  {"N", 0},
  {"M", 0},
  {"<", ",", 0},
  {">", ".", 0},
  {"?", "/", 0},
  {"Shift", 0},
  {"Select", 0},
  {"UpArrow", 0},
  {"Next", 0},
  {"1", 0},
  {"2", 0},
  {"3", 0},
  {"Tab", 0},

  /* Row 6 */

  {"Print", "Enter", 0},
  {"Extend", "char", 0},
  {" ", 0},
  {"Extend", "char", 0},
  {"LeftArrow", 0},
  {"DownArrow", 0},
  {"RightArrow", 0},
  {"0", 0},
  {".", 0}
};

==> xkeycaps_2.42.orig.tar.gz: xkeycaps-2.42/kbds/hpitf-caps.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the key surfaces of the HP 300, 400, and 700 series
 * keyboards.  By Dave Brooks <dbrooks@inel.gov>
 */

static const struct key_strings hpitf_caps [] = {

  /* Row 0 */

  {"Reset", "Break", 0},
  {"Stop", 0},
  {"F1", 0},
  {"F2", 0},
  {"F3", 0},
  {"F4", 0},
  {"Menu", 0},
  {"User", "System", 0},
  {"F5", 0},
  {"F6", 0},
  {"F7", 0},
  {"F8", 0},
  {"Clear", "line", 0},
  {"Clear", "display", 0},
  {"F9", 0},
  {"F10", 0},
  {"F11", 0},
  {"F12", 0},

  /* Row 2 */

  {"~", "`", 0},
  {"!", "1", 0},
  {"@", "2", 0},
  {"#", "3", 0},
  {"$", "4", 0},
  {"%", "5", 0},
  {"^", "6", 0},
  {"&", "7", 0},
  {"*", "8", 0},
  {"(", "9", 0},
  {")", "0", 0},
  {"_", "-", 0},
  {"+", "=", 0},
  {"Backspace", 0},
  {"Insert", "line", 0},
  {"Delete", "line", 0},
  {"*", 0},
  {"/", 0},
  {"+", 0},
  {"-", 0},

  /* Row 3 */

  {"Tab", 0},
  {"Q", 0},
  {"W", 0},
  {"E", 0},
  {"R", 0},
  {"T", 0},
  {"Y", 0},
  {"U", 0},
  {"I", 0},
  {"O", 0},
  {"P", 0},
  {"{", "[", 0},
  {"}", "]", 0},
  {"|", "\\", 0},
  {"Insert", "char", 0},
  {"Delete", "char", 0},
  {"7", 0},
  {"8", 0},
  {"9", 0},
  {"Enter", 0},

  /* Row 4 */

  {"Caps", 0},
  {"Ctrl", 0},
  {"A", 0},
  {"S", 0},
  {"D", 0},
  {"F", 0},
  {"G", 0},
  {"H", 0},
  {"J", 0},
  {"K", 0},
  {"L", 0},
  {":", ";", 0},
  {"\"", "'", 0},
  {"Return", 0},
  {"Home", 0},
  {"Prev", 0},
  {"4", 0},
  {"5", 0},
  {"6", 0},
  {",", 0},

  /* Row 5 */

  {"Del", "Esc", 0},
  {"Shift", 0},
  {"Z", 0},
  {"X", 0},
  {"C", 0},
  {"V", 0},
  {"B", 0},
  {"N", 0},
  {"M", 0},
  {"<", ",", 0},
  {">", ".", 0},
  {"?", "/", 0},
  {"Shift", 0},
  {"Select", 0},
  {"UpArrow", 0},
  {"Next", 0},
  {"1", 0},
  {"2", 0},
  {"3", 0},
  {"Tab", 0},

  /* Row 6 */

  {"Print", "Enter", 0},
  {"Extend", "char", 0},
  {" ", 0},
  {"Extend", "char", 0},
  {"LeftArrow", 0},
  {"DownArrow", 0},
  {"RightArrow", 0},
  {"0", 0},
  {".", 0}
};
